<?php
/**
 * @package			No Boss Extensions
 * @subpackage  	No Boss Image Gallery
 * @author			No Boss Technology <contact@nobosstechnology.com>
 * @copyright		Copyright (C) 2018 No Boss Technology. All rights reserved.
 * @license			GNU Lesser General Public License version 3 or later; see <https://www.gnu.org/licenses/lgpl-3.0.en.html>
 */

defined('JPATH_PLATFORM') or die;

// verificacao necessaria, caso contrario um erro acontece na geracao de tema
if(!class_exists('JFormFieldNobossbinaryfile')){
    require JPATH_LIBRARIES . '/noboss/forms/fields/nobossbinaryfile.php'; 
}
class JFormFieldNobossimageupload extends JFormFieldNobossbinaryfile
{
	
	/**
	 * Method to get the field input markup.
	 *
	 * @return  string	The field input markup.
	 * @since   1.6
	 */
	protected function getInput()
	{
        // Pega o documento.
        $doc = JFactory::getDocument();
        // guarda o id da imagem que esta salvo no banco na tabela separada de imagens do image gallery
        $imageId = $this->form->getData()->get('image_id');
        // Flag que verifica se já o foi cadastrado uma imagem pra esse item
        $hasValue = !empty($imageId);
        // inicia a variavel q vai guardar o src da imagem para exibi-la no subform
        $this->src = "";
        // Verifica se tem valor.
        if($hasValue){
            // pega o atributo src
            $this->src = $this->getSrc($imageId);
        }
        
        // Verifica se não tem registro e configura classe hidden do campo.
        $classHidden = ($hasValue) ? "" : " hidden";

        // Pega o label do campo.
        $translatedLabel =  JText::_($this->getAttribute('label'));

        // Pega o label do botão de upload.
        $translatedLabelUploadButton = JText::_($this->getAttribute('label_upload_button'));

        // Pega o label do link visualização do arquivo.
        $translatedLabelViewFile = JText::_($this->getAttribute('label_view_file'));

        // Pega o label do link para excluir o arquivo.
        $translatedLabelDeleteImage = JText::_($this->getAttribute('label_delete_file'));

        // URL para requisição do campo.
        // FIXME: atualizar para J5
        $url = "index.php?option=com_nobossajax&library=noboss.file.binaryfromfile&method=getBinaryFromFile&format=json&restrict_dimensions=1";

        // Carrega bilbioteca de leitura de arquivos binários da No Boss.
        // FIXME: atualizar para J5
        JLoader::register('NobossBinaryfromfile', JPATH_LIBRARIES . "/noboss/file/binaryfromfile.php");

        // Cria um objeto com a classe que trata leitura binária.
        $nobossfilebinaryfile = new NobossBinaryfromfile();

        if($this->getAttribute('extension')){
            // Pega parâmetros do contexto do campo.
            $params = $nobossfilebinaryfile->getParams($this->getAttribute('extension'));

            $paramFileExtensionsGranted = $params->get("file_upload_extensions_granted");
            // Verifica se o valor do parâmetro de extensões permitidas é vazio e atribui um valor default.
            $extensionGranted = (empty($paramFileExtensionsGranted)) ? "*" : implode(",", $paramFileExtensionsGranted);
            // Verifica se o valor do parâmetro de limite de tamanho de arquivo é vazio
            $sizeLimitUploadFileInBytes = $params->get("size_limit_upload_file");
            $attributeMaxFileSize = (empty($sizeLimitUploadFileInBytes)) ? "" : " data-max-size=" . $sizeLimitUploadFileInBytes;
        }

        // Cria objeto para armazenar informações de contexto do campo.
        $dataParamsField = new \stdClass();
        $dataParamsField->msg_error_max_file_size = JText::_($this->getAttribute("msg_error_max_file_size"));
        $dataParamsField->msg_error_extension_file_granted = JText::_($this->getAttribute("msg_error_extension_file_granted"));

        // Transforma os dados para json.
        $jsonDataParamsField = json_encode($dataParamsField);

        // Trata caracteres especiais para inserção no atributo value do campo.
        $valueDataParamsField = htmlspecialchars($jsonDataParamsField);

        // Monta o HTML do campo.
        $html =
            <<<HTML
            <div class="file-upload-context" id="{$this->getAttribute('id')}">
                <div class="file-upload upload-button">
HTML;

        // Pega contexto da aplicação joomla.
        $app = JFactory::getApplication();
        // data attribute para identificar que eh um item novo (se ja tiver imagem cadastrada vai ser false)
        $dataNew = $hasValue ? "false" : "true";
        // atributo required, colocado apenas quando nao tem imagem cadastrada
        $required = $hasValue ? "" : "required='required'";
        $html .=
            <<<HTML
                    <input {$required} name="upload_{$this->getAttribute('name')}" accept=".jpg,.png,.gif" class="upload {$this->getAttribute('class')}" type="file" aria-label="{$translatedLabel}" data-id="upload-binary" data-new="{$dataNew}" data-update="false" data-params-field="{$valueDataParamsField}" data-url="{$url}">
                    <input type="hidden" name="{$this->getAttribute('name')}" value="{$this->value}" {$this->mimeTypeFile} data-id="upload-binary-hidden">
                </div>
                <div class="tooltip-image">
                    <img name="{$this->getAttribute('name')}" class="thumb" src="{$this->src}" data-id="upload-binary-img">
                </div>
            </div>
HTML;
        
        // Carrega javascript para funcionamento do campo
        $doc->addScript(JURI::root().'libraries/noboss/forms/fields/assets/js/min/'.$this->type.'.min.js');
        $doc->addStylesheet(JURI::base()."../modules/mod_nobossimagegallery/fields/assets/stylesheets/css/nobossimageupload.min.css");
        
        return $html;
    }

    /**
	 * Busca informacoes da imagem para construir o atributo src
	 *
     * @param   int     $imageId id da imagem a ser obtido o binario
	 * @return  string  atributo src da imagem
	 */
    public function getSrc($imageId){
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query->select('content_image, mime_type')
            ->from('#__noboss_image_gallery_file')
            ->where('id_file = ' . (int) $imageId);
        $db->setQuery($query);
        $imageData = $db->loadObject();
         
        // Configura mime type para o arquivo.
        $attributeMime = "mime='#mimeTypeFile#'";
        $mimeTypeFile = (empty($imageData->mime_type)) ? "" : $imageData->mime_type;
        $mimeTypeFile = str_replace("#mimeTypeFile#", $mimeTypeFile, $attributeMime);
        $attributeSrc = "";
        // Verifica se o mime type do arquivo possui image.
        if(strstr($mimeTypeFile, "image") != false){
            // Configura conteúdo src da tag img do campo.
            $attributeSrc = "data:#mimeTypeFile#;base64,#stringFile#";
            $attributeSrc = str_replace("#mimeTypeFile#", $mimeTypeFile, $attributeSrc );
            $stringFile = (empty($imageData->content_image)) ? "" : $imageData->content_image;
            $attributeSrc = str_replace("#stringFile#", $stringFile, $attributeSrc);
        }
    
        // retorna o atributo src que sera usado para exibir a imagem que esta cadastrada neste item
        return $attributeSrc;
    }
}
