<?php
/**
 * @package			No Boss Extensions
 * @subpackage  	No Boss Image Gallery
 * @author			No Boss Technology <contact@nobosstechnology.com>
 * @copyright		Copyright (C) 2018 No Boss Technology. All rights reserved.
 * @license			GNU Lesser General Public License version 3 or later; see <https://www.gnu.org/licenses/lgpl-3.0.en.html>
 */

defined ( '_JEXEC' ) or die ();

/**
 * Helper da extensao Image Gallery
 */
abstract class modNobossimagegalleryHelper {

    /**
	 * Obtem fotos cadastradas manualmente atraves do loadmode 'Manual'
	 *
	 * @param   object   $items Itens cadastrados no admin
	 *
	 * @return  array  retorna os itens contendo os atributos src para imagem e thumb
	 */
    public static function getManualPhotos($items){
        // percorre cada item cadastrado (que contem apenas seu id e legenda)
        $items = array_map(function($item){
            // chama metodo que monta o atributo src para a imagem e thumb
            $itemData = self::getSrc($item->image_id);
            // adiciona o src da thumb no item atual
            $item->thumbSrc = $itemData['thumb_src'];
            // adiciona o src da imagem no item atual
            $item->imageSrc = $itemData['image_src'];
            // retorna o item em formato de array
            return (array)$item;
        }, (array) $items);
        // retorna array contendo os itens com os atributos src
        return $items;
    }


    /**
	 * Busca informacoes da imagem para construir o atributo src
	 *
     * @param   int     $imageId id da imagem a ser obtido o binario
	 * @return  string  atributo src da imagem
	 */
    public static function getSrc($imageId){
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query->select('content_thumb, content_image, mime_type')
            ->from('#__noboss_image_gallery_file')
            ->where('id_file = ' . (int) $imageId);
        $db->setQuery($query);
        $imageData = $db->loadObject();
       
        // Configura mime type para o arquivo.
        $attributeMime = "mime='#mimeTypeFile#'";
        $mimeTypeFile = (empty($imageData->mime_type)) ? "" : $imageData->mime_type;
        $mimeTypeFile = str_replace("#mimeTypeFile#", $mimeTypeFile, $attributeMime);
        $imageSrc = "";
        $thumbSrc = "";
        // Verifica se o mime type do arquivo possui image.
        if(strstr($mimeTypeFile, "image") != false){
            // Configura conteúdo src da tag img (para a imagem ampliada e thumb)
            $imageSrc = "data:#mimeTypeFile#;base64,#stringFile#";
            $imageSrc = str_replace("#mimeTypeFile#", $mimeTypeFile, $imageSrc );
            $stringFile = (empty($imageData->content_image)) ? "" : $imageData->content_image;
            $imageSrc = str_replace("#stringFile#", $stringFile, $imageSrc);

            $thumbSrc = "data:#mimeTypeFile#;base64,#stringFile#";
            $thumbSrc = str_replace("#mimeTypeFile#", $mimeTypeFile, $thumbSrc );
            $stringFile = (empty($imageData->content_thumb)) ? "" : $imageData->content_thumb;
            $thumbSrc = str_replace("#stringFile#", $stringFile, $thumbSrc);
        }
        
        // retorna o atributo src que sera usado para exibir a imagem que esta cadastrada neste item
        return array('thumb_src' => $thumbSrc, 'image_src' => $imageSrc);
    }

	/**
	 * Obtem fotos de um album do flickr
	 *
	 * @param   string   $api  		  	Api do flickr
	 * @param   string   $idAlbum  	  Id do álbum do flickr
	 * @param   string   $idItemMenu  Format de consulta
	 *
	 * @return  array
	 */
	public static function getPhotos($api, $idAlbum, $format = 'php_serial') {

		$params = array (
				'api_key' => $api,
				'method' => 'flickr.photosets.getPhotos',
				'photoset_id' => $idAlbum,
				'format' => $format,
				'media' => 'photo',
				'extras' => 'description'
		);

		$encodedParams = array ();

		foreach ( $params as $k => $v ) {

			$encodedParams [] = urlencode ( $k ) . '=' . urlencode ( $v );
		}

		$url = "https://www.flickr.com/services/rest/?" . implode ( '&', $encodedParams );

		$ch = curl_init ();

		curl_setopt ( $ch, CURLOPT_URL, $url );

		curl_setopt ( $ch, CURLOPT_RETURNTRANSFER, 1 );

		curl_setopt ( $ch, CURLOPT_SSL_VERIFYPEER, false );

		$photos = unserialize ( curl_exec ( $ch ) );

		// Erro ao acessar a conta
		if ($photos['stat'] == 'fail') {
			return false;
		}

		return $photos ;
	}

	/**
	 * Obtem lista de albums de uma conta
	 *
	 * @param   string   $api  		  Api do flickr
	 * @param   string   $userId  	  Id do usuário do flickr
	 * @param   string   $format 	  Format de consulta
     * 
     * https://www.flickr.com/services/api/flickr.photosets.getList.html
	 *
	 * @return  array
	 */
	public static function getPhotoSets($api, $userId, $format = 'php_serial') {
		$params = array (
				'method' => 'flickr.photosets.getList',
				'api_key' => $api,
				'user_id' => $userId,
				'format' => $format
		);

		$encoded_params = array ();

		foreach ( $params as $k => $v ) {

			$encoded_params [] = urlencode ( $k ) . '=' . urlencode ( $v );
		}
		$url = "https://www.flickr.com/services/rest/?" . implode ( '&', $encoded_params );

		$ch = curl_init ();

		curl_setopt ( $ch, CURLOPT_URL, $url );

		curl_setopt ( $ch, CURLOPT_RETURNTRANSFER, 1 );

		curl_setopt ( $ch, CURLOPT_SSL_VERIFYPEER, false );

		$sets = unserialize ( curl_exec ( $ch ) );

		if ($sets ['stat'] == 'fail') {

			switch ($sets ["code"]) {
				case 1 :
					return "<b>User not found<b>: The user NSID passed was not a valid user NSID and the calling user was not logged in.";
					break;
                case 2 :
                    return "<b>Continuation key is invalid or expired<b>: The continuation key passed was not valid or has already expired.";
                    break;
				case 100 :
					return "<b>Invalid API Key<b>: The API key passed was not valid or has expired.";
					break;
				case 105 :
					return "<b>Service currently unavailable<b>: The requested service is temporarily unavailable.";
					break;
				case 106 :
					return "<b>Write operation failed<b>: The requested operation failed due to a temporary issue.";
					break;
				case 111 :
					return "<b>Format not found<b>: The requested response format was not found.";
					break;
				case 112 :
					return "<b>Method not found<b>: The requested method was not found.";
					break;
				case 114 :
					return "<b>Invalid SOAP envelope<b>: The SOAP envelope send in the request could not be parsed.";
					break;
				case 115 :
					return "<b>Invalid XML-RPC Method Call<b>: The XML-RPC request document could not be parsed.";
					break;
				case 116 :
					return "<b>Bad URL found<b>: One or more arguments contained a URL that has been used for abuse on Flickr.";
					break;
				default:
					return "An unknown error occurred in the Flickr API request.";
			}
		} else {
			return $sets ['photosets'] ['photoset'];
		}
    }
    
    /**
	 * Salva o binario da imagem e da thumb no banco de dados
	 *
	 * @return  string resposta em formato json
	 */
    public static function insertImagesAjax() {
        // Pega dados da requisição.
		$app = JFactory::getApplication();
        $input = $app->input;
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        
        // id escondido da imagem
        $hiddenId = $input->get('hiddenId');
        // dados da imagem
        $imageData = json_decode(utf8_decode($input->get('image', '', 'post')));
        // binario da imagem
        $fileBinary = $imageData->stringFile;
        // tipo mime da imagem
        $mimeType = $imageData->mimeTypeFile;
        // binario da thumb
        $thumbBinary = utf8_decode($input->get('thumb', '', 'post'));
        // colunas a serem usadas na query de insert
        $columns = array('id_file', 'content_image', 'content_thumb', 'mime_type');
        // constroi a query
        $query->insert($db->quoteName('#__noboss_image_gallery_file'))
            ->columns($db->quoteName($columns))
            ->values((int) $hiddenId . "," . $db->quote("$fileBinary") . "," . $db->quote("$thumbBinary") . "," . $db->quote("$mimeType"));
        $db->setQuery($query);
        // array de resposta da requisicao
        $response = array();
        // tenta executar
        try{
            $db->execute();
            // caso execute com sucesso, seta na resposta flag de sucesso e o id dessa imagem no banco
            $response['success'] = true;
        }catch(Exception $e){
            // seta flag de sem sucesso em caso de erro
            $response['success'] = false;
        }
        // retorna a resposta em json
        exit(json_encode($response));
    }

    /**
	 * Atualiza o conteudo binario de uma imagem no banco
	 *
	 * @return  string resposta em formato json
	 */
    public static function updateImagesAjax() {
        // Pega dados da requisição.
		$app = JFactory::getApplication();
        $input = $app->input;
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        
        // id escondido da imagem
        $hiddenId = $input->get('hiddenId');
        // dados da imagem
        $imageData = json_decode(utf8_decode($input->get('image', '', 'post')));
        // binario da imagem
        $fileBinary = $imageData->stringFile;
        // tipo mime da imagem
        $mimeType = $imageData->mimeTypeFile;
        // binario da thumb
        $thumbBinary = utf8_decode($input->get('thumb', '', 'post'));
        // colunas a serem usadas na query de update
        $fields = array(
            $db->quoteName('mime_type') . ' = ' . $db->quote($mimeType),
            $db->quoteName('content_image') . ' = ' . $db->quote($fileBinary),
            $db->quoteName('content_thumb') . ' = ' . $db->quote($thumbBinary)
        );
        // condicoes a serem usadas no where da query
        $conditions = array(
            $db->quoteName('id_file') . ' = ' . (int) $hiddenId
        );
        // constroi a query
        $query->update($db->quoteName('#__noboss_image_gallery_file'))
            ->set($fields)
            ->where($conditions);
        $db->setQuery($query);
        // array de resposta da requisicao
        $response = array();
        // tenta executar
        try{
            $db->execute();
            // caso execute com sucesso, seta na resposta flag de sucesso e o id dessa imagem no banco
            $response['success'] = true;
        }catch(Exception $e){
            // seta flag de sem sucesso em caso de erro
            $response['success'] = false;
        }
        // retorna a resposta em json
        exit(json_encode($response));
    }

    /**
	 * Deleta registros de imagens salvas no banco
	 *
	 * @return  string resposta em formato json
	 */
    public static function deleteImagesAjax() {
        // Pega dados da requisição.
		$app = JFactory::getApplication();
        $input = $app->input;
        // pega o array de ids das imagens que devem ser excluidas
        $deleteIds = json_decode(utf8_decode($input->get('imageIds', '', 'post')));
        // junta elas separando por virgula
        $deleteIds = implode(",", $deleteIds);
         // id do modulo onde essas imagens foram cadastradas
        $moduleId = $input->get('moduleId');
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        // monta o where da query, informando os ids a serem excluidos e o id do modulo
        $conditions = array(
            $db->quoteName('id_file') . ' IN (' . $deleteIds . ')'
        );
        // constroi a query de delete
        $query->delete($db->quoteName('#__noboss_image_gallery_file'))
            ->where($conditions);
        $db->setQuery($query);
        // tenta executar
        try{
            $db->execute();
            // caso execute com sucesso, seta na resposta flag de sucesso e o id dessa imagem no banco
            $response['success'] = true;
        }catch(Exception $e){
            // seta flag de sem sucesso em caso de erro
            $response['success'] = false;
        }
        // retorna a resposta em json
        exit(json_encode($response));
    }

    public static function getExistentIdsAjax(){
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        // constroi a query que busca pelos ids de imagens
        $query->select('id_file')
            ->from('#__noboss_image_gallery_file');
        $db->setQuery($query);
        $response = array();
        // tenta executar
        try{
            $response = $db->loadColumn();
        }catch(Exception $e){
        }
        exit(json_encode($response));
    }

    /**
	 * Verifica se No Boss Library esta instalada no site e caso nao esteja, forca uma atualizacao e recarrega a pagina
     * 
     * OBS: essa acao eh necessaria para contornar problema em atualizacoes da library no processo do Joomla que as vezes mantem ela removida
	 *
	 * @return  void
	 */
    public static function checkLibraryInstallation(){
        // Library da No Boss nao localizada: inicia instalacao forcada da library
        if(!JFolder::exists(JPATH_LIBRARIES.'/noboss')) {
            try {
                // Adiciona diretorio de models do componente installer do Joomla
                JModelLegacy::addIncludePath(JPATH_ADMINISTRATOR . '/components/com_installer/models');
                // Instancia model de extensoes
                $modelInstaller = JModelLegacy::getInstance('install', 'InstallerModel');
                $input = JFactory::getApplication()->input;
                
                // Versao macro do Joomla (ex: 5)
                $joomlaVersion = substr(JVERSION, 0, 1);

                $urlXml = "https://www.nobossextensions.com/repository/extras/nobosslibrary/xml.xml";
                $urlInstallation = "https://www.nobossextensions.com/en/installation/nobosslibrary/";

                // Objeto com conteudo do arquivo XML que controla as atualizacoes da extensao
                $xmlUpdates = simplexml_load_file($urlXml);

                // Percorre todas versoes de update do xml
                for($i=0; $i < count($xmlUpdates->update); $i++){
                    // Possui atributo que identifica a versao da extensao
                    if(isset($xmlUpdates->update[$i]->attributes()['nbjoomla'])){
                        // Obtem qual eh a versao do Joomla (ex: 'current', '3', '4') no item de update do XML
                        $xmlUpdateJoomlaVersion = $xmlUpdates->update[$i]->attributes()['nbjoomla'];

                        // Item eh da mesma versao que estamos da extensao: adiciona versao do joomla na url de instalacao
                        if($xmlUpdateJoomlaVersion == $joomlaVersion){
                            $urlInstallation .= "joomla{$joomlaVersion}/";
                        }
                    }
                }
                
                // Seta para utilizar metodo de instalacao via url
                $input->set('installtype', 'url');
                // Seta a url de instalacao da library
                $input->set('install_url', $urlInstallation);

                // Executa metodo de instalacao
                $modelInstaller->install();
            } catch (Exception $e) {
                // Nao tem tratamento de erro pq o Joomla joga diversas vezes a falta de permissoes como erro sendo que ocorreu tudo certo
            }

            // Library foi instalada com sucesso
            if(JFolder::exists(JPATH_LIBRARIES.'/noboss')) {
                // Recarrega a pagina
                header("Refresh:0");
                exit;
            }
            else{
                return false;
            }
        }
        return true;
    }

    /**
	 * Funcao executada antes de qualquer acao de update do joomla
     * 
	 * @param   JUpdate       $update  An update definition
     * @param   JTableUpdate  $table   The update instance from the database
	 */
    public static function prepareUpdate($update, $table){
        jimport('noboss.util.installscript');

        // Token da licenca
        $token = str_replace('token=', '', $update->get('extra_query'));

        if (method_exists('NoBossUtilInstallscript','updateLicenseIsValid')){
            // Busca no servidor da No Boss se extensao possui permissao para update
            $return = NoBossUtilInstallscript::updateLicenseIsValid($token);
            
            // Token nao localizado
            if ($return == 'INVALID_TOKEN'){
                $msg = "<b>There are problems with the extension license:</b> <br /><br /> &bull; Your extension token was not found on the No Boss Extensions platform. <br /><br />";
                JFactory::getApplication()->enqueueMessage($msg, 'error');
                return false;
            }
            // Extensao nao possui suporte valido
            else if($return == 'INVALID'){
                $msg = "<b>License with expired update period:</b> <br /><br /> &bull; To update the extension, it is necessary to renew the license support period. <br /> &bull; You can renew the support time by accessing the tab called 'License' available within the edition of any extension registration. <br /><br />";
                JFactory::getApplication()->enqueueMessage($msg, 'error');
                return false;
            }
        }
    }
}
