<?php
/**
 * @package			No Boss Extensions
 * @subpackage  	No Boss Image Gallery
 * @author			No Boss Technology <contact@nobosstechnology.com>
 * @copyright		Copyright (C) 2018 No Boss Technology. All rights reserved.
 * @license			GNU Lesser General Public License version 3 or later; see <https://www.gnu.org/licenses/lgpl-3.0.en.html>
 */

defined('_JEXEC') or die;

// Bibliotecas a importar
jimport('joomla.filesystem.folder');
jimport('noboss.util.loadextensionassets');
jimport('noboss.util.fonts');
jimport('noboss.util.url');

// Carrega helper do módulo.
JLoader::register('modNobossimagegalleryHelper', __DIR__ . '/helper.php');

// Verifica se no boss library esta instalada: se ainda nao estiver, tenta instalar e se ainda nao der retorna false
if(!modNobossimagegalleryHelper::checkLibraryInstallation()){
    return;
}

$app = JFactory::getApplication();
// pega o template vinculado a pagina
$tmpl = $app->getTemplate(true);
// pega os parametros do template
$tmplParams = $tmpl->params;
// pega a cor primaria setada nos parametros do template
$tmplPrimaryColor = $tmplParams->get('primary_color');
// pega a cor secundaria setada nos parametros do template
$tmplSecondaryColor = $tmplParams->get('secondary_color');


// Parametro com nome do modulo nao esta definido
if (!isset($module->name)){
    $module->name = str_replace('mod_', '', $module->module);
}
$moduleName = $module->name;
$extensionName = "mod_" . $module->name;

// Instancia objeto da classe para obter o diretorio da extensao
$assetsObject = new NoBossUtilLoadExtensionAssets("lib_noboss");
// Obtem diretorio da extensao
$extensionPath = $assetsObject->getDirectoryExtension(false);
// Carrega arquivo traducao para extensao especificada
JFactory::getLanguage()->load("lib_noboss", $extensionPath);

$doc = JFactory::getDocument();
$ds = DIRECTORY_SEPARATOR;

// variável que armazena o tema escolhido 
$theme = json_decode($params->get("theme"));
$theme = $theme->theme;

// verifica qual eh o modo de carregamento e pega o subform de acordo com a opcao
$loadMode = $params->get('itemsloadmode');
if($loadMode == "manual"){
    // se for manual, pega o subform com name igual ao tema escolhido
    $itemParams = $params->get($theme);
}else{
    // se for um modo externo, pega o subform com name igual da opcao de modo de carregamento
    $itemParams = $params->get($loadMode);
    $itemParams = (array)$itemParams;
    $itemParams = reset($itemParams);
    $itemParams = (object)$itemParams;

    if(empty($itemParams)){
        return;
    }
}

if($loadMode == "flickr_album"){
    // Dados da galeria (conta e álbum)
    $data 			= modNobossimagegalleryHelper::getPhotos($itemParams->api_flickr, $itemParams->id_album_flickr);
    $photos 		= $data['photoset']['photo'];
    $urlPhotoSet 	=  "http://www.flickr.com/photos/{$data['photoset']['owner']}/sets/{$data['photoset']['id']}";
}else{
    $photos = modNobossimagegalleryHelper::getManualPhotos($itemParams);
}
$countPhotos 	= (!empty($photos)) ? count($photos) : 0;

// armazema estilo da seção, elemento mais externo do html 
$sectionStyle = "";
// armazema estilo da seção para o mobile, elemento mais externo do html 
$sectionStyleMobile = "";

// string com o nome da modal da área externa concatenado com o modelo selecionado 
$externalAreaXml = $theme . '_external_area_customization';
// variável que armazena o objeto com os parâmetros da modal de área externa do tema selecionado  
$externalArea = json_decode($params->get($externalAreaXml));
// string com o nome da modal de itens concatenado com o modelo selecionado 
$itemsCustomizationXml = $theme . '_items_customization';
// variável que armazena o objeto com os parâmetros da modal de itens do tema selecionado  
$itemsCustomization = json_decode($params->get($itemsCustomizationXml));

// Verifica se usuário definiu para exibir as imagens da galeria em ordem inversa
$reverseOrderImages = $itemsCustomization->display_order;
// armazena a cor que fica atras das imagens antes de carrega-las
// pega a cor definida no modulo ou a cor primaria do template
$itemsCustomization->image_background_color = !empty($itemsCustomization->image_background_color) ? $itemsCustomization->image_background_color : $tmplPrimaryColor;
$backgroundImageColor = $itemsCustomization->image_background_color;

// verifica se um album foi carregado
if(!is_null($photos)){
	// Inverter ordem das imagens
	if ($reverseOrderImages == 'desc'){
		$photos = array_reverse($photos);
	// Embaralhar a ordem 
	} else if ($reverseOrderImages == 'shuffle'){
		shuffle($photos);
	}
}

// Ajustes manuais da área externa caso exista valor
if ($externalArea->external_area_display_mode){
    if(!empty($externalArea->external_area_width)){
        $sectionStyle .= 'margin-left: auto !important; margin-right: auto !important; width:' . $externalArea->external_area_width . '%;';
    }
    if(!empty($externalArea->external_area_width_mobile)){
        $sectionStyleMobile .= 'width:' . $externalArea->external_area_width_mobile . '% !important; ';
    }
}
// verifica qual o modo de exibição
// 1: é manual, então exibe container
// 0: é full width 
if($externalArea->content_display_mode){
    $itemColumns = !empty($externalArea->content_columns) ? "nb-lg-{$externalArea->content_columns} nb-md-{$externalArea->content_columns} nb-sm-{$externalArea->content_columns} nb-xs-12" : "";
}

// armazena o estilo do espaçamento interno na variável que é colocada no elemento mais externo
$sectionStyle .= ' padding: ' . implode(' ', $externalArea->external_area_inner_space) . '; ';
// armazena o estilo do espaçamento interno para o mobile na variável que é colocada no elemento mais externo
$sectionStyleMobile .= 'padding: ' . implode(' ', $externalArea->external_area_inner_space_mobile) . ' !important; ';
// armazena o estilo do espaçamento externo na variável que é colocada no elemento mais externo
$sectionStyle .= ' margin: ' . implode(' ', $externalArea->external_area_outer_space) . '; ';
// armazena o estilo do espaçamento externo na variável que é colocada no elemento mais externo
$sectionStyleMobile .= 'margin: ' . implode(' ', $externalArea->external_area_outer_space_mobile) . ' !important;';

// Armazena o tipo de fundo da area externa (cor ou gradiente)
$backgroundType = $externalArea->external_area_background_type;

// Se o tipo de fundo for "cor"
// pega a cor definida no modulo ou a cor primaria do template
$externalArea->external_area_background_color = !empty($externalArea->external_area_background_color) ? $externalArea->external_area_background_color : $tmplPrimaryColor;
if($backgroundType == "background-color" && !empty($externalArea->external_area_background_color)){
    // Armazena essa cor ao estilo de fundo da secao
    $sectionStyle .= "background-color: {$externalArea->external_area_background_color};";
}elseif($backgroundType == "background-gradient"){
    // Se o tipo for gradiente, acresenta o CSS de gradiente ao estilo da seção
    $gradient1 = $externalArea->external_area_gradient_filter_1;
    $gradient2 = $externalArea->external_area_gradient_filter_2;
    $sectionStyle .= "background: {$gradient2}; ";
    $sectionStyle .= "background: -webkit-linear-gradient(to right, {$gradient1}, {$gradient2}); "; 
    $sectionStyle .= "background: linear-gradient(to right, {$gradient1}, {$gradient2}); ";
}

// Parâmetros para título (área externa)
$showTitle = $params->get('show_title');
$title = rtrim($params->get('title'));
$titleTagHtml	= $externalArea->title_tag_html;
$titleStyle = "";
$titleStyle .= NoBossUtilFonts::importNobossfontlist($externalArea->title_font);
$titleStyle .= " text-align: {$externalArea->title_alignment};";
$titleStyle .= " text-transform: {$externalArea->title_transform};";
// pega a cor definida no modulo ou a cor primaria do template
$externalArea->title_color = !empty($externalArea->title_color) ? $externalArea->title_color : $tmplPrimaryColor;
$titleStyle .= " color: {$externalArea->title_color};";
$titleSize = $externalArea->title_size;
if(!empty($titleSize)){
	$titleSizeEm = $titleSize/16;
	$titleStyle .= " font-size: {$titleSize}px; font-size: {$titleSizeEm}em;";
}
$titleStyleMobile = "";
if(isset($externalArea->title_size_mobile)){
	$titleSizeMobile = $externalArea->title_size_mobile;
	$titleSizeMobileEm = $titleSizeMobile/16;
	$titleStyleMobile = " font-size: {$titleSizeMobile}px; font-size: {$titleSizeMobileEm}em !important;";
}
if(isset($externalArea->title_space)){
	$titleStyle .= " padding:".implode(" ", $externalArea->title_space).';';
}

// Parâmetros para texto de apoio (área externa)
$showSubtitle = $params->get('show_subtitle');
$subtitle = nl2br(rtrim($params->get('subtitle')));
$subtitleTagHtml = $externalArea->subtitle_tag_html;
$subtitleStyle = "";
$subtitleStyle .= NoBossUtilFonts::importNobossfontlist($externalArea->subtitle_font);
$subtitleStyle .= " text-align: {$externalArea->subtitle_alignment};";
$subtitleStyle .= " text-transform: {$externalArea->subtitle_transform};";
// pega a cor definida no modulo ou a cor primaria do template
$externalArea->subtitle_color = !empty($externalArea->subtitle_color) ? $externalArea->subtitle_color : $tmplPrimaryColor;
$subtitleStyle .= " color: {$externalArea->subtitle_color};";
$subtitleSize = $externalArea->subtitle_size;
if(!empty($subtitleSize)){
	$subtitleSizeEm = $subtitleSize/16;
	$subtitleStyle .= " font-size: {$subtitleSize}px; font-size: {$subtitleSizeEm}em;";
}
$subtitleStyleMobile = "";
if(isset($externalArea->subtitle_size_mobile)){
	$subtitleSizeMobile = $externalArea->subtitle_size_mobile;
	$subtitleSizeMobileEm = $subtitleSizeMobile/16;
	$subtitleStyleMobile = " font-size: {$subtitleSizeMobile}px; font-size: {$subtitleSizeMobileEm}em !important;";
}
if(isset($externalArea->subtitle_space)){
	$subtitleStyle .= " padding:".implode(" ", $externalArea->subtitle_space).';';
}

if($theme === 'model2'){
    if($externalArea->content_display_mode === '1'){
        $displayOverflow = $externalArea->display_overflow;
    }

    if((!empty($displayOverflow)) && ($displayOverflow === 'right')){
        $containerHeight = ' height: '.$itemsCustomization->height.'px; ';
        $containerHeightMobile = ' height: '.$itemsCustomization->height_mobile.'px !important; ';
        $displayLateralFade = $externalArea->display_lateral_fade;
    }

    $displayLayout = $itemsCustomization->display_layout;
    if($displayLayout === 'grid'){
        $gridLayout = $itemsCustomization->grid_layout;
    }

    if(isset($itemsCustomization->hover_style)){
        $hoverStyle = $itemsCustomization->hover_style;

        $imageHoverStyle = "";
        if($hoverStyle === 'filter-border'){
            
            $imageHoverStyle .= ' background-color: '.$itemsCustomization->image_filter_hover.'; ';

            $borderSizeHover = implode(' ', $itemsCustomization->border_size_hover);
            $borderColorHover = $itemsCustomization->border_color_hover;
            $borderHoverStyle = " border-style: solid !important; border-width: {$borderSizeHover} !important; border-color: {$borderColorHover} !important; ";

        }else if($hoverStyle === 'fade'){
            $imageHoverStyle .= ' background-color: rgba(0,0,0,0.75); ';
        }
    }
}

// Parametrizações de transicao dos itens
$jsConfig = new \stdClass();
if($theme === 'model1'){
    $jsConfig->autoAdjustImage = $itemsCustomization->auto_adjust_image == '0' ? 'contain' : 'cover';
    $jsConfig->autoAdjustImageMobile = !empty($itemsCustomization->auto_adjust_image_mobile) && $itemsCustomization->auto_adjust_image_mobile == '0' ? 'contain' : 'cover';
    $jsConfig->fullScreen = $itemsCustomization->enable_full_screen == '1' ? true : false;
    $jsConfig->autoPlay = $itemsCustomization->enable_auto_play == '1' ? true : false;
    $jsConfig->autoPlayInterval = intval($itemsCustomization->auto_play_interval) * 1000;
    $jsConfig->thumbsPosition = $itemsCustomization->thumbs_position;
    $jsConfig->orientation = $itemsCustomization->thumbs_position == 'left' || $itemsCustomization->thumbs_position == 'right' ? 'vertical' : 'horizontal';
    $jsConfig->thumbsArrowsFade = $itemsCustomization->arrows_fade ? true : false;
}
$jsConfig->drag = $itemsCustomization->enable_drag == '1' ? true : false;
$jsConfig->slideArrowsFade = $itemsCustomization->arrows_fade ? true : false;

$jsConfig->height = !empty($itemsCustomization->height) ? intval($itemsCustomization->height) : 500;
$jsConfig->heightMobile = !empty($itemsCustomization->height_mobile) ? intval($itemsCustomization->height_mobile) : 450;
if($theme === 'model2'){
    $jsConfig->width = !empty($itemsCustomization->width) ? intval($itemsCustomization->width) : 500;
    $jsConfig->widthMobile = !empty($itemsCustomization->width) ? intval($itemsCustomization->width_mobile) : 450;
    $jsConfig->forceSize = isset($displayOverflow) && $displayOverflow !== 'none' ? 'fullWidth' : 'none';
}

// usada na tmpl para armazenar a descrição da imagem 
$description = "";

// Parametrização das setas
// armazena o estilo das setas
$arrowsStyle = "";
// armazena o estilo das setas no hover
$arrowsStyleHover = "";
// armazena se deve exibir setas
$showArrows = $itemsCustomization->show_arrows;
// armazena se deve exibir setas na imagem ampliada
$amplifiedImageArrows = $itemsCustomization->show_arrows_amplified_image; 
$thumbsArrows = 'none';
if($theme === 'model1'){
    // armazena se deve exibir setas nas thumbs
    $thumbsArrows = $itemsCustomization->show_arrows_thumbs; 
}

// variavel que armazenara o arredondamento da borda da seta
$arrowsBorderRadius="";
// variavel que armazenara o arredondamento da borda da seta nas thumbs
$thumbsBorderRadius="";

// se deve exibir as setas
if($showArrows && ($amplifiedImageArrows != 'none' || $thumbsArrows != 'none')){
	$arrowsIcon = $itemsCustomization->arrows_icon;
	$arrowsIconSize = $itemsCustomization->arrows_icon_size;
	$thumbsArrowsIconSize = $itemsCustomization->arrows_icon_size;
	// se o tamanho dos icones for maior que 32
	if($arrowsIconSize > 32){
		// diminui o tamanho da seta nas thumbs
		$thumbsArrowsIconSize = $arrowsIconSize/2;
	}
	if(!empty($thumbsArrowsIconSize)){
		// definicao do estilo das setas nas thumbs
		$thumbsArrowsIconSizeEm = $thumbsArrowsIconSize/16;
		$thumbsArrowsMarginTop = $thumbsArrowsIconSizeEm/2;
		$thumbsArrowsMarginTop = "margin-top: -{$thumbsArrowsMarginTop}em;";
		$thumbsArrowsIconSize = "font-size: {$thumbsArrowsIconSize}px; font-size: {$thumbsArrowsIconSizeEm}em;";
	}
	if(!empty($arrowsIconSize)){
		// definicao do estilo das setas
		$arrowsIconSizeEm = $arrowsIconSize/16;
		$arrowsMarginTop = $arrowsIconSizeEm/2;
		$arrowsMarginTop = "margin-top: -{$arrowsMarginTop}em;";
		$arrowsIconSize = "font-size: {$arrowsIconSize}px; font-size: {$arrowsIconSizeEm}em;";
	}
	// se o arredondamento da borda da seta for maior que 3
	if($itemsCustomization->arrows_border_radius > 3){
		// diminui o arredondamento da borda da seta das thumbs
		$thumbsBorderRadius = $itemsCustomization->arrows_border_radius/2;
	}

	// armazena se deve exibir cor de fundo nas setas
	$showBackgroundArrows = $itemsCustomization->show_arrows_background;
	
	// espacamento das setas
	$arrowsStyle .= "padding: " . implode(' ', $itemsCustomization->arrows_spacing) . ";";
	if ($itemsCustomization->show_arrows_border_radius && !empty($itemsCustomization->arrows_border_radius)){
		// arredondamento da borda das setas 
		$arrowsBorderRadius = 'border-radius:' . $itemsCustomization->arrows_border_radius . 'px;';
		$thumbsBorderRadius = 'border-radius:' . $thumbsBorderRadius . 'px;';
    }
    // pega a cor definida no modulo ou a cor primaria do template
    $itemsCustomization->arrows_background = !empty($itemsCustomization->arrows_background) ? $itemsCustomization->arrows_background : $tmplPrimaryColor;
	if ($itemsCustomization->show_arrows_background && !empty($itemsCustomization->arrows_background)){
		// cor de fundo e de hover das setas
        $arrowsStyle .= "background-color: {$itemsCustomization->arrows_background}; ";
        // pega a cor definida no modulo ou a cor secundaria do template
        $itemsCustomization->arrows_background_hover = !empty($itemsCustomization->arrows_background_hover) ? $itemsCustomization->arrows_background_hover : $tmplSecondaryColor;
		$arrowsStyleHover .= "background-color: {$itemsCustomization->arrows_background_hover} !important; ";
	}
	if ($itemsCustomization->show_arrows_border && !empty($itemsCustomization->arrows_border_color)){
		// borda das setas
		$arrowsStyle .= "border: 1px solid  {$itemsCustomization->arrows_border_color}; ";
    }
    // pega a cor definida no modulo ou a cor primaria do template
    $itemsCustomization->arrows_color = !empty($itemsCustomization->arrows_color) ? $itemsCustomization->arrows_color : $tmplPrimaryColor;
	if (!empty($itemsCustomization->arrows_color)){
		// cor das setas
		$arrowsStyle .= " color: {$itemsCustomization->arrows_color};";
	}
}

if($theme === 'model1'){
    // Parametrização das thumbs
    $showThumbs = $itemsCustomization->show_thumbs;
    if($showThumbs){
        // estilo da thumb ativa, sendo 0 = opacidade e 1 = highlight
        $thumbsActiveStyle = $itemsCustomization->active_thumb_style;
        // opacidade das imagens nao abertas
        $nonActivesOpacity = $itemsCustomization->not_actives_opacity;
        // cor da borda da imagem ativa
        // pega a cor definida no modulo ou a cor primaria do template
        $itemsCustomization->highlight_border_color = !empty($itemsCustomization->highlight_border_color) ? $itemsCustomization->highlight_border_color : $tmplPrimaryColor;
        $highlightBorderColor = $itemsCustomization->highlight_border_color;
    }
}

// Dados para legenda (texto de apoio das imagens)
if($loadMode == "flickr_album"){
    $showLegend = $itemParams->show_legend;
}
if($theme === 'model1'){
    $legendLimit = $itemsCustomization->legend_limit;
}
$showLegendBackground = $itemsCustomization->show_legend_background;
$legendBackground = $itemsCustomization->legend_background;
$legendTagHtml = $itemsCustomization->legend_tag_html;
// variavel que armazenara o estilo das legendas das imagens
$legendStyle = "";
$legendStyle .= NoBossUtilFonts::importNobossfontlist($itemsCustomization->legend_font);
$legendStyle .= " text-align: {$itemsCustomization->legend_alignment};";
$legendStyle .= " text-transform: {$itemsCustomization->legend_transform};";
// pega a cor definida no modulo ou a cor primaria do template
$itemsCustomization->legend_color = !empty($itemsCustomization->legend_color) ? $itemsCustomization->legend_color : $tmplPrimaryColor;
$legendStyle .= " color: {$itemsCustomization->legend_color};";
$legendSize = $itemsCustomization->legend_size;
if(!empty($legendSize)){
	$legendSizeEm = $legendSize/16;
	$legendStyle .= " font-size: {$legendSize}px; font-size: {$legendSizeEm}em;";
}	
$legendStyleMobile = "";
if(isset($itemsCustomization->legend_size_mobile)){
	$legendSizeMobile = $itemsCustomization->legend_size_mobile;
	$legendSizeMobileEm = $legendSizeMobile/16;
	$legendStyleMobile = " font-size: {$legendSizeMobile}px; font-size: {$legendSizeMobileEm}em !important;";
}

// verifica se deve exibir fundo nas legendas 
if($showLegendBackground != "none" && !empty($legendBackground)){
	$legendStyle .= "background-color: {$legendBackground};";
	if($showLegendBackground == "inline-block"){
		if($itemsCustomization->legend_alignment == 'left'){
			$legendStyle .= "left: 1em;";
		}elseif ($itemsCustomization->legend_alignment == 'right') {
			$legendStyle .= "right: 1em;";
		}else{
			$legendStyle .= "margin-top: -50px; position: relative; display: table;";
		}
	}
	else{
		$legendStyle .= "left: 1em; right: 1em; text-align: {$itemsCustomization->legend_alignment};";
	}
}else if(isset($itemsCustomization->show_text_shadow)){
	if($itemsCustomization->show_text_shadow){
		$legendStyle .= " text-shadow: 2px 1px 3px {$itemsCustomization->text_shadow_color};";
	}
}

if($theme === 'model2'){
    $legendStyleModal = "";

    $itemsCustomization->legend_color_modal = !empty($itemsCustomization->legend_color_modal) ? $itemsCustomization->legend_color_modal : $tmplPrimaryColor;
    $legendStyleModal .= " color: {$itemsCustomization->legend_color_modal};";
    if(isset($itemsCustomization->legend_modal_space)){
        $legendStyleModal .= " padding:".implode(' ', $itemsCustomization->legend_modal_space).'; ';
    }

    $showLegendBackgroundModal = $itemsCustomization->show_legend_background_modal;
    $legendBackgroundModal = $itemsCustomization->legend_background_modal;

    // verifica se deve exibir fundo nas legendas 
    if($showLegendBackgroundModal != "none" && !empty($legendBackgroundModal)){
        $legendStyleModal .= "background-color: {$legendBackgroundModal};";
        if($showLegendBackgroundModal == "inline-block"){
            if((!empty($itemsCustomization->legend_alignment_modal)) && ($itemsCustomization->legend_alignment_modal == 'left')){
                $legendStyleModal .= "left: 1em;";
            }elseif ((!empty($itemsCustomization->legend_alignment_modal)) && ($itemsCustomization->legend_alignment_modal == 'right')) {
                $legendStyleModal .= "right: 1em;";
            }else{
                $legendStyleModal .= "margin-top: -50px; position: relative; display: table;";
            }
        }
        else{
            $legendStyleModal .= "left: 1em; right: 1em; text-align: {$itemsCustomization->legend_alignment_modal};";
        }
    }else if(isset($itemsCustomization->show_text_shadow_modal)){
        if($itemsCustomization->show_text_shadow_modal){
            $legendStyleModal .= " text-shadow: 2px 1px 3px {$itemsCustomization->text_shadow_color_modal};";
        }
    }

    $showBorder = $itemsCustomization->show_border;
    if($showBorder){
        $borderSize = implode(' ', $itemsCustomization->border_size);
        $borderColor = $itemsCustomization->border_color;
        $borderStyle = " border-style: solid; border-width: {$borderSize}; border-color: {$borderColor}; ";
    }

    $modalAdaptToScreen = $itemsCustomization->adapt_to_screen;

    $modalStyle = "";
    $modalStyle .= " background-color: {$itemsCustomization->modal_background}; ";
    $modalStyle .= " padding:".implode(' ', $itemsCustomization->modal_space).'; ';

    $modalStyleMobile = "";
    $modalStyleMobile .= " padding:".implode(' ', $itemsCustomization->modal_space_mobile).' !important; ';

    $closeButtonStyle = "";
    if(isset($itemsCustomization->close_button_size)){
        $closeButtonSize = $itemsCustomization->close_button_size;
        $closeButtonSizeEm = $closeButtonSize/16;
        $closeButtonStyle .= " font-size: {$closeButtonSize}px; font-size: {$closeButtonSizeEm}em !important;";
    }
    $closeButtonStyle .= " padding:".implode(' ', $itemsCustomization->close_button_space).'; ';
    $closeButtonStyle .= " background-color: {$itemsCustomization->close_button_background}; ";
    $closeButtonStyle .= " color: {$itemsCustomization->close_button_color}; ";
    $closeButtonStyle .= " border-radius: {$itemsCustomization->close_button_border_radius}px; ";

    $closeButtonStyleMobile = "";
    if(isset($itemsCustomization->close_button_size_mobile)){
        $closeButtonSizeMobile = $itemsCustomization->close_button_size_mobile;
        $closeButtonSizeMobileEm = $closeButtonSizeMobile/16;
        $closeButtonStyleMobile .= " font-size: {$closeButtonSizeMobile}px; font-size: {$closeButtonSizeMobileEm}em !important;";
    }
    $closeButtonStyleMobile .= " padding:".implode(' ', $itemsCustomization->close_button_space_mobile).' !important; ';
}


// verifica se existem fotos a serem exibidas
if(!empty($photos)){
	// Define prefixo a ser utilizado na insercao de codigos inline para CSS e JS
	$prefixCodeJsAndCss = "[module-id={$module->name}_{$module->id}]";

	// Obtem informacoes de codigos JS e CSS a serem inseridos
	$loadJs	 		= '1';
    $loadCss 		= '1';
    $overwritingJs	= (!empty($params->get('overwriting_js'))) ? rtrim($params->get('overwriting_js')) : '';
    $overwritingCss	= (!empty($params->get('overwriting_css'))) ? rtrim($params->get('overwriting_css')) : '';

	// Instancia objeto passando o nome da extensao com prefixo (ex: 'mod_nobossbanners')
	$assetsObject = new NoBossUtilLoadExtensionAssets($extensionName, $prefixCodeJsAndCss);

	// Adiciona arquivos e codigos JS (se definido para exibir)
	$assetsObject->loadJs($loadJs, array('code' => $overwritingJs));

    // Adiciona arquivo CSS para uma familia de fontes
    $assetsObject->loadFamilyIcons("font-awesome");

	// Adiciona arquivos e codigos CSS (se definido para carregar)
	$assetsObject->loadCss($loadCss, array('code' => $overwritingCss));
	JFactory::getDocument()->addStylesheet(JUri::root() . 'modules/mod_nobossimagegallery/assets/site/css/plugins/nbslider.min.css');
	// Renderiza o arquivo com os estilos 
	require JModuleHelper::getLayoutPath($extensionName, 'style/' . $theme);
	// Renderiza o modulo
	require JModuleHelper::getLayoutPath($extensionName, 'theme/'.$params->get('layout', $theme));
}
